Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(19)

Unified Diff: ash/system/network/network_icon.h

Issue 2913103002: Add Tether to Mobile NetworkTypePattern. (Closed)
Patch Set: Add Tether to Mobile NetworkTypePattern. Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ash/system/network/network_icon.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/system/network/network_icon.h
diff --git a/ash/system/network/network_icon.h b/ash/system/network/network_icon.h
index 827cacc20695822eb2517cf962f69cf4b3f61c0a..a7b264032387f469aa276f6ac0741762f500361b 100644
--- a/ash/system/network/network_icon.h
+++ b/ash/system/network/network_icon.h
@@ -55,9 +55,9 @@ ASH_EXPORT base::string16 GetLabelForNetwork(
const chromeos::NetworkState* network,
IconType icon_type);
// Updates and returns the appropriate message id if the cellular network
// is uninitialized.
-ASH_EXPORT int GetCellularUninitializedMsg();
+ASH_EXPORT int GetMobileUninitializedMsg();
// Gets the correct icon and label for |icon_type|. Also sets |animating|
// based on whether or not the icon is animating (i.e. connecting).
« no previous file with comments | « no previous file | ash/system/network/network_icon.cc » ('j') | no next file with comments »
@@ -55,9 +55,9 @@ ASH_EXPORT base::string16 GetLabelForNetwork(
const chromeos::NetworkState* network,
IconType icon_type);
-// Updates and returns the appropriate message id if the cellular network
+// Updates and returns the appropriate message id if the mobile network
// is uninitialized.

Powered by Google App Engine
This is Rietveld 408576698